@@ -16,7 +16,7 @@ use Path::Tiny 'path';
 use Text::Diff ();
 use Try::Tiny qw( try catch finally );
 
-our $VERSION = '1.25'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 sub init {
     my $self = _new( shift, 'expect_no_root_dir' );
@@ -763,7 +763,7 @@ App::Dest - Deployment State Manager
 
 =head1 VERSION
 
-version 1.25
+version 1.26
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/dest.svg)](https://travis-ci.org/gryphonshafer/dest)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/dest/badge.png)](https://coveralls.io/r/gryphonshafer/dest)
@@ -1113,8 +1113,8 @@ Let's then also say that the C<example/ls/deploy> file contains: C<ls>
 
 I could create a deployment file C<example/dest.wrap> that looked like this:
 
-    #!/bin/bash
-    /bin/bash "$1"
+    #!/bin/sh
+    /bin/sh "$1"
 
 Wrappers will only ever be run from the current code. For example, if you have
 a revert file for some action and you checkout your working directory to a
